.. _recipe_asr.polarizability:

asr.polarizability
==================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.polarizability`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.polarizability.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.polarizability

or as a python module

.. code-block:: console

   $ python -m asr.polarizability

Detailed description
--------------------
Optical polarizability.

Steps
-----


asr.polarizability
^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.polarizability.main
   